@@ -121,6 +121,13 @@ void do_cleanup(void){
     radar_cleanup();
 }
 
+void sigabort(int i){
+    // Not exactly safe, but everything is blowing up anyway
+    do_cleanup();
+    signal(SIGABRT, SIG_DFL);
+    abort();
+}
+
 void init_dock(int argc, char **argv){
     sscanf(wmweather_master_xpm[0], "%d %d %*s", &wmweather_mask_width, &wmweather_mask_height);
     wmweather_mask_bits=malloc((wmweather_mask_width+7)/8*wmweather_mask_height);
@@ -178,6 +185,8 @@ void init_dock(int argc, char **argv){
         warn("Error setting SIGPIPE signal handler!");
     if(signal(SIGTERM, sigfunc)==SIG_ERR)
         warn("Error setting SIGTERM signal handler!");
+    if(signal(SIGABRT, sigabort)==SIG_ERR)
+        warn("Error setting SIGABRT signal handler!");
 
     DrawDisplay(1);
 }
