@@ -26,6 +26,8 @@
 #include "die.h"
 #include "download.h"
 
+static const char *user_agent = "wmweather+/" VERSION;
+
 static CURLM *multi_handle=NULL;
 struct download_info {
     CURL *handle;
@@ -235,6 +237,7 @@ int download_file(char *filename, char *from_addr, char *postdata, int flags, vo
        curl_easy_setopt(info->handle, CURLOPT_FAILONERROR, 1)!=CURLE_OK ||
        curl_easy_setopt(info->handle, CURLOPT_AUTOREFERER, 1)!=CURLE_OK ||
        curl_easy_setopt(info->handle, CURLOPT_FOLLOWLOCATION, 1)!=CURLE_OK ||
+       curl_easy_setopt(info->handle, CURLOPT_USERAGENT, user_agent)!=CURLE_OK ||
        curl_easy_setopt(info->handle, CURLOPT_TIMEOUT, 10*60)!=CURLE_OK ||
        curl_easy_setopt(info->handle, CURLOPT_PRIVATE, info)!=CURLE_OK
       ){
