@@ -595,6 +595,8 @@ int readconf(char *file){
         }
         if(!parse_option(c, d)){
             warn("%s[%d]: %s", file, l, error);
+            fclose(fp);
+            if(!flag) free(file);
             return 2;
         }
     }
@@ -725,11 +727,11 @@ int main(int argc, char **argv){
     }
     if(i) exit(1);
     if(viewer==NULL) viewer="xless";
-    if(metar_uri==NULL) metar_uri="http://weather.noaa.gov/pub/data/observations/metar/stations/%s.TXT";
+    if(metar_uri==NULL) metar_uri="http://tgftp.nws.noaa.gov/data/observations/metar/stations/%s.TXT";
     if(avn_uri==NULL) avn_uri="http://www.nws.noaa.gov/cgi-bin/mos/getmav.pl?sta=%s";
     if(eta_uri==NULL) eta_uri="http://www.nws.noaa.gov/cgi-bin/mos/getmet.pl?sta=%s";
     if(mrf_uri==NULL) mrf_uri="http://www.nws.noaa.gov/cgi-bin/mos/getmex.pl?sta=%s";
-    if(warning_uri==NULL) warning_uri="http://weather.noaa.gov/pub/data/watches_warnings/%f/%.2z/%z.txt";
+    if(warning_uri==NULL) warning_uri="http://tgftp.nws.noaa.gov/data/watches_warnings/%f/%.2z/%z.txt";
 
     download_init(email_address);
     init_dock(argc, argv);
